OC.L10N.register(
    "mail",
    {
    "Important" : "Tähtis",
    "Work" : "Töö",
    "Personal" : "Isiklik",
    "Later" : "Hiljem",
    "Mail" : "Kirjad",
    "Name" : "Nimi",
    "Mail address" : "E-posti aadress",
    "Password" : "Parool",
    "IMAP Host" : "IMAP server",
    "None" : "Pole",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP kasutaja",
    "IMAP Password" : "IMAP parool",
    "SMTP Host" : "SMTP server",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP kasutaja",
    "SMTP Password" : "SMTP parool",
    "Connecting" : "Ühendamine",
    "Save" : "Salvesta",
    "Connect" : "Ühenda",
    "Aliases" : "Aliased",
    "Signature" : "Allkiri",
    "Go back" : "Mine tagasi",
    "Email address" : "E-posti aadress",
    "Cancel" : "Loobu",
    "General" : "Üldine",
    "List" : "Nimekiri",
    "Register" : "Registreeru",
    "Keyboard shortcuts" : "Klaviatuuri otseteed",
    "Archive" : "Arhiiv",
    "Delete" : "Kustuta",
    "Search" : "Otsi",
    "Send" : "Saada",
    "Refresh" : "Värskenda",
    "From" : "Saatja",
    "To" : "Saaja",
    "Subject" : "Teema",
    "Enter a date" : "Sisesta kuupäev",
    "Choose a file to add as attachment" : "Vali fail, mida manustada",
    "Choose" : "Vali",
    "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
    "Confirm" : "Kinnita",
    "Favorite" : "Lemmik",
    "Read" : "Lugemine",
    "Edit tags" : "Muuda silte",
    "Back" : "Tagasi",
    "Create event" : "Lisa sündmus",
    "All day" : "Kogu päev",
    "Description" : "Kirjeldus",
    "Create" : "Loo",
    "Select" : "Vali",
    "Comment" : "Kommentaar",
    "Accept" : "Nõustu",
    "Decline" : "Keeldu",
    "Remove" : "Eemalda",
    "email" : "e-post",
    "Other" : "Muu",
    "Forward" : "Edasi",
    "Translate" : "Tõlgi",
    "Choose a folder to store the attachment in" : "Vali kaust, kuhu manus salvestada",
    "Unnamed" : "Nimeta",
    "Move" : "Liiguta",
    "Quota" : "Kvoot",
    "Saving" : "Salvestamine",
    "Remove account" : "Eemalda konto",
    "Mark all as read" : "Märgi loetuks",
    "Rename" : "Nimeta ümber",
    "Clear cache" : "Tühjenda puhver",
    "New message" : "Uus sõnum",
    "Retry" : "Proovi uuesti",
    "Sending …" : "Saadan ...",
    "Reply" : "Vasta",
    "Message" : "Sõnum",
    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
    "Add" : "Lisa",
    "Close" : "Sulge",
    "Date" : "Kuupäev",
    "Tags" : "Sildid",
    "Clear" : "Tühjenda",
    "Custom" : "Kohandatud",
    "Tag already exists" : "Silt on juba olemas",
    "Copy translated text" : "Kopeeri tõlgitud tekst",
    "Actions" : "Tegevused",
    "Priority" : "Prioriteet",
    "Reset" : "Lähtesta",
    "Client ID" : "Kliendi ID",
    "Client secret" : "Kliendi salasõna",
    "User" : "Kasutaja",
    "Host" : "Host",
    "Port" : "Port",
    "Valid until" : "Kehtib kuni",
    "Certificate" : "Sertifikaat",
    "Submit" : "Saada",
    "Account connected" : "Konto ühendatud",
    "All" : "Kõik",
    "Drafts" : "Mustandid",
    "Favorites" : "Lemmikud",
    "All inboxes" : "Kõik postkastid",
    "Inbox" : "Postkast",
    "Junk" : "Tämpspost",
    "Sent" : "Saadetud",
    "Trash" : "Prügikast",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Error loading message" : "Tõrge kirja laadimisel",
    "Forwarding to %s" : "Edasta %s",
    "Redirect" : "Suunamine"
},
"nplurals=2; plural=(n != 1);");
